==> Appium-Python-Client-2.6.0.tar.gz: Appium-Python-Client-2.6.0/appium/options/android/common/avd/avd_launch_timeout_option.py <==
# Licensed to the Software Freedom Conservancy (SFC) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The SFC licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from datetime import timedelta
from typing import Optional, Union

from appium.options.common.supports_capabilities import SupportsCapabilities

AVD_LAUNCH_TIMEOUT = 'avdLaunchTimeout'


class AvdLaunchTimeoutOption(SupportsCapabilities):
    @property
    def avd_launch_timeout(self) -> Optional[timedelta]:
        """
        Timeout to wait until Android Emulator is started.
        """
        value = self.get_capability(AVD_LAUNCH_TIMEOUT)
        return None if value is None else timedelta(milliseconds=value)

    @avd_launch_timeout.setter
    def avd_launch_timeout(self, value: Union[timedelta, int]) -> None:
        """
        Maximum timeout to wait until Android Emulator is started.
        60000 ms by default.
        """
        self.set_capability(AVD_LAUNCH_TIMEOUT, value.microseconds // 1000 if isinstance(value, timedelta) else value)

==> Appium-Python-Client-2.10.1.tar.gz: Appium-Python-Client-2.10.1/appium/options/android/common/avd/avd_launch_timeout_option.py <==
# Licensed to the Software Freedom Conservancy (SFC) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The SFC licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from datetime import timedelta
from typing import Optional, Union

from appium.options.common.supports_capabilities import SupportsCapabilities

AVD_LAUNCH_TIMEOUT = 'avdLaunchTimeout'


class AvdLaunchTimeoutOption(SupportsCapabilities):
    @property
    def avd_launch_timeout(self) -> Optional[timedelta]:
        """
        Timeout to wait until Android Emulator is started.
        """
        value = self.get_capability(AVD_LAUNCH_TIMEOUT)
        return None if value is None else timedelta(milliseconds=value)

    @avd_launch_timeout.setter
    def avd_launch_timeout(self, value: Union[timedelta, int]) -> None:
        """
        Maximum timeout to wait until Android Emulator is started.
        60000 ms by default.
        """
        self.set_capability(
            AVD_LAUNCH_TIMEOUT, int(value.total_seconds() * 1000) if isinstance(value, timedelta) else value
        )
